VenturoApiManager class

Main class for managing API requests

Properties

baseUrl String
Base API URL
latefinal
config VenturoApiConfig?
API configuration
latefinal
dio Dio
Dio instance for making requests
latefinal
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

defaultDioInstance([String? baseUrl]) Dio
Returns a new Dio instance
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

api VentDioMixin
Returns the main API client instance
no setter
getToken String
Retrieves the authentication token
no setter
instance VenturoApiManager
Returns the singleton instance of VenturoApiManager
no setter
setToken String
Sets the authentication token
no getter

Static Methods

initialize({required String baseUrl, Dio? dioInstance, VenturoApiConfig? config, Iterable<Interceptor>? interceptors}) Future<void>
Initializes the Venturo API Manager